========
torch-cv
========


.. image:: https://img.shields.io/travis/RJaikanth/torchcv.svg
        :target: https://travis-ci.com/RJaikanth/torchcv

.. image:: https://readthedocs.org/projects/torchcv/badge/?version=latest
        :target: https://torchcv.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Short Description


* Free software: MIT license
* Documentation: https://torchcv.readthedocs.io.


Features
--------

* TODO